@@ -1,7 +1,7 @@
 package Data::CSel;
 
-our $DATE = '2016-09-10'; # DATE
-our $VERSION = '0.10'; # VERSION
+our $DATE = '2016-11-23'; # DATE
+our $VERSION = '0.11'; # VERSION
 
 use 5.020000;
 use strict;
@@ -674,6 +674,11 @@ sub csel {
     my $pexpr = parse_csel($expr);
     $pexpr or die "Invalid CSel expression '$expr'";
 
+    local $Code::Includable::Tree::NodeMethods::GET_PARENT_METHOD   = $opts->{get_parent_method}   if $opts->{get_parent_method};
+    local $Code::Includable::Tree::NodeMethods::SET_PARENT_METHOD   = $opts->{set_parent_method}   if $opts->{set_parent_method};
+    local $Code::Includable::Tree::NodeMethods::GET_CHILDREN_METHOD = $opts->{get_children_method} if $opts->{get_children_method};
+    local $Code::Includable::Tree::NodeMethods::SET_CHILDREN_METHOD = $opts->{set_children_method} if $opts->{set_children_method};
+
     my @res = _uniq_objects(map { _sel($opts, $_, @nodes) } @$pexpr );
 
     if ($opts->{wrap}) {
@@ -699,7 +704,7 @@ Data::CSel - Select tree node objects using CSS Selector-like syntax
 
 =head1 VERSION
 
-This document describes version 0.10 of Data::CSel (from Perl distribution Data-CSel), released on 2016-09-10.
+This document describes version 0.11 of Data::CSel (from Perl distribution Data-CSel), released on 2016-11-23.
 
 =head1 SYNOPSIS
 
@@ -1286,7 +1291,8 @@ A tree node object is any regular Perl object satisfying the following criteria:
 object, or undef if object is the root node); 2) it supports a C<children>
 method which should return a list (or an arrayref) of children node objects
 (where the list/array will be empty for a leaf node). Note: you can use
-L<Role::TinyCommons::Tree::Node> to enforce this requirement.
+L<Role::TinyCommons::Tree::Node> to enforce this requirement. Note: the
+C<parent> and C<children> method names can actually be customized, see options.
 
 Known options:
 
@@ -1308,6 +1314,42 @@ If set to true, instead of returning a list of matching nodes, the function will
 return a L<Data::CSel::Selection> object instead (which wraps the result, for
 convenience). See the selection object's documentation for more details.
 
+=item * get_parent_method => str
+
+Example:
+
+ get_parent_method => 'get_parent'
+
+This option can be used if your node object uses method other than the default
+C<parent> to get parent node.
+
+=item * set_parent_method => str
+
+Example:
+
+ set_parent_method => 'set_parent'
+
+This option can be used if your node object uses method other than the default
+C<parent> to set parent node.
+
+=item * get_children_method => str
+
+Example:
+
+ get_children_method => 'get_children'
+
+This option can be used if your node object uses method other than the default
+C<children> to get children nodes.
+
+=item * set_children_method => str
+
+Example:
+
+ set_children_method => 'set_children'
+
+This option can be used if your node object uses method other than the default
+C<children> to set children nodes.
+
 =back
 
 =head2 parse_csel($expr) => hash|undef
